package com.ruoyi.zongzhi.service;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcSafetyDanger;

/**
 * 监管单位Service接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface ITcSafetyDangerService 
{
    /**
     * 查询监管单位
     * 
     * @param id 监管单位主键
     * @return 监管单位
     */
    public TcSafetyDanger selectTcSafetyDangerById(Long id);

    /**
     * 查询监管单位列表
     * 
     * @param tcSafetyDanger 监管单位
     * @return 监管单位集合
     */
    public List<TcSafetyDanger> selectTcSafetyDangerList(TcSafetyDanger tcSafetyDanger);

    /**
     * 新增监管单位
     * 
     * @param tcSafetyDanger 监管单位
     * @return 结果
     */
    public int insertTcSafetyDanger(TcSafetyDanger tcSafetyDanger);

    /**
     * 修改监管单位
     * 
     * @param tcSafetyDanger 监管单位
     * @return 结果
     */
    public int updateTcSafetyDanger(TcSafetyDanger tcSafetyDanger);

    /**
     * 批量删除监管单位
     * 
     * @param ids 需要删除的监管单位主键集合
     * @return 结果
     */
    public int deleteTcSafetyDangerByIds(Long[] ids);

    /**
     * 删除监管单位信息
     * 
     * @param id 监管单位主键
     * @return 结果
     */
    public int deleteTcSafetyDangerById(Long id);
}
